@@ -20,11 +20,11 @@ TIMEOUT_SEC = 60
 # this file will contian all the handlers and code for settings
 # code can be more modular i think but not bothering now
 # todo make the code more modular
-no = "disabled - "
-yes = "enabled - "
+no = "✖"
+yes = "✔"
 # Central object is not used its Acknowledged 
 tordb = tkdb()
-header =  '<b>tk - a telegram leecher bot.\n</b>\n<u>user settings menu</u>'
+header =  '<b>tgtk - a telegram leecher bot.\n</b>\n<u>user settings menu</u>'
 async def handle_user_setting_callback(e):
     db = tordb
     sender_id = str(e.sender_id)
@@ -45,7 +45,7 @@ async def handle_user_setting_callback(e):
     elif cmd[1] == "rclonemenu":
         # this is menu
         mmes = await e.get_message()
-        await handle_user_settings(mmes,True,"\nrclone config menu. TD= Team Drive, ND= Normal Drive",submenu="rclonemenu",sender_id=sender_id)
+        await handle_user_settings(mmes,True,"\nWelcome to Rclone Config Menu. TD= Team Drive, ND= Normal Drive",submenu="rclonemenu",sender_id=sender_id)
     elif cmd[1] == "thumbmenu":
         # this is menu
         mmes = await e.get_message()
@@ -65,7 +65,7 @@ async def handle_user_setting_callback(e):
         await general_input_manager(e,mmes,"THUMBNAIL","str",val,sender_id,"thumbmenu")  
 
     elif cmd[1] == "selfdest":
-        await e.answer("Closed")
+        await e.answer("closed.")
         await e.delete()
     elif cmd[1] == "change_drive":
         await e.answer(f"changed default drive to {cmd[2]}.",alert=True)
@@ -115,7 +115,7 @@ async def handle_user_settings(e,edit=False,msg="",submenu=None,sender_id=None):
         await get_sub_menu("open thumbnail menu","thumbmenu",sender_id,menu)#
         # thumbnail
         menu.append(
-            [KeyboardButtonCallback("close Menu",f"usettings selfdest {sender_id}".encode("UTF-8"))]
+            [KeyboardButtonCallback("close menu.",f"usettings selfdest {sender_id}".encode("UTF-8"))]
         )
 
 
@@ -152,7 +152,7 @@ async def handle_user_settings(e,edit=False,msg="",submenu=None,sender_id=None):
 
         await get_sub_menu("go back ⬅️","mainmenu",sender_id,menu)
         menu.append(
-            [KeyboardButtonCallback("Close Menu",f"usettings selfdest {sender_id}".encode("UTF-8"))]
+            [KeyboardButtonCallback("close menu",f"usettings selfdest {sender_id}".encode("UTF-8"))]
         )
         if edit:
             rmess = await e.edit(header+"\nit is recommended to lock the group before setting vars.\n"+msg,parse_mode="html",buttons=menu,link_preview=False)
@@ -167,16 +167,16 @@ async def handle_user_settings(e,edit=False,msg="",submenu=None,sender_id=None):
             await get_bool_variable("DISABLE_THUMBNAIL","Disable Thumbnail",menu,"disablethumb",sender_id)
             await get_sub_menu("go back ⬅️","mainmenu",sender_id,menu)
             menu.append(
-                [KeyboardButtonCallback("Close Menu",f"usettings selfdest {sender_id}".encode("UTF-8"))]
+                [KeyboardButtonCallback("close menu",f"usettings selfdest {sender_id}".encode("UTF-8"))]
             )
             await e.edit(header+"\nmanage your thumbnail(s) on the fly.", file=thumb, buttons=menu, parse_mode="html")
         else:
             menu.append(
-                [KeyboardButtonCallback("Set Thumbnail.", f"usettings setthumb {sender_id}".encode("UTF-8"))]
+                [KeyboardButtonCallback("set thumbnail.", f"usettings setthumb {sender_id}".encode("UTF-8"))]
             )
-            await get_sub_menu("Go Back ⬅️","mainmenu",sender_id,menu)
+            await get_sub_menu("go back ⬅️","mainmenu",sender_id,menu)
             menu.append(
-                [KeyboardButtonCallback("Close Menu",f"usettings selfdest {sender_id}".encode("UTF-8"))]
+                [KeyboardButtonCallback("close menu",f"usettings selfdest {sender_id}".encode("UTF-8"))]
             )
             await e.edit(header+"\nmanage your thumbnail(s) on the fly.", parse_mode="html", buttons=menu)
 
@@ -217,7 +217,7 @@ async def general_input_manager(e,mmes,var_name,datatype,value,sender_id,sub_men
                             #SessionVars.update_var("LEECH_ENABLED",True)
                         except Exception:
                             torlog.error(traceback.format_exc())
-                            await handle_user_settings(mmes,True,f"<b><u>The configuration file is invalid, check logs.</b></u>",sub_menu)
+                            await handle_user_settings(mmes,True,f"<b><u>the configuration file is invalid, check logs.</b></u>",sub_menu)
                             return
                     elif var_name == "THUMBNAIL":
                         try:
@@ -239,15 +239,15 @@ async def general_input_manager(e,mmes,var_name,datatype,value,sender_id,sub_men
                         #db.set_variable(var_name,value)
                         #SessionVars.update_var(var_name,value)
                     
-                    await handle_user_settings(mmes,True,f"<b><u>Received {var_name} value '{value}' with confirm.</b></u>",sub_menu, sender_id=sender_id)
+                    await handle_user_settings(mmes,True,f"<b><u>received {var_name} value '{value}' with confirm.</b></u>",sub_menu, sender_id=sender_id)
                 except ValueError:
-                    await handle_user_settings(mmes,True,f"<b><u>Value [{value}] not valid try again and enter {datatype}.</b></u>",sub_menu, sender_id=sender_id)    
+                    await handle_user_settings(mmes,True,f"<b><u>value [{value}] not valid try again and enter {datatype}.</b></u>",sub_menu, sender_id=sender_id)    
             else:
-                await handle_user_settings(mmes,True,f"<b><u>Confirm differed by user.</b></u>",sub_menu, sender_id=sender_id)
+                await handle_user_settings(mmes,True,f"<b><u>confirm differed by user.</b></u>",sub_menu, sender_id=sender_id)
         else:
-            await handle_user_settings(mmes,True,f"<b><u>Confirm timed out [waited 60s for input].</b></u>",sub_menu, sender_id=sender_id)
+            await handle_user_settings(mmes,True,f"<b><u>confirm timed out [waited 60s for input].</b></u>",sub_menu, sender_id=sender_id)
     else:
-        await handle_user_settings(mmes,True,f"<b><u>Entry Timed out [waited 60s for input]. OR else ignored.</b></u>",sub_menu, sender_id=sender_id)
+        await handle_user_settings(mmes,True,f"<b><u>entry timed out [waited 60s for input].</b></u>",sub_menu, sender_id=sender_id)
 
 
 async def get_value(e,file=False,photo=False):
@@ -348,7 +348,7 @@ async def get_confirm_callback(e,o_sender,lis):
 
 async def confirm_buttons(e,val):
     # add the confirm buttons at the bottom of the message
-    await e.edit(f"Confirm the input :- <u>{val}</u>",buttons=[KeyboardButtonCallback("Yes","confirmsetting true"),KeyboardButtonCallback("No","confirmsetting false")],parse_mode="html")
+    await e.edit(f"confirm the input : <u>{val}</u>",buttons=[KeyboardButtonCallback("yes","confirmsetting true"),KeyboardButtonCallback("no","confirmsetting false")],parse_mode="html")
 
 async def get_bool_variable(var_name,msg,menu,callback_name,sender_id):
     # handle the vars having bool values
@@ -380,9 +380,9 @@ async def get_string_variable(var_name,menu,callback_name,sender_id):
     if var_name == "RCLONE_CONFIG":
         rfile = user_db.get_rclone(sender_id)
         if rfile is False:
-            val = "File is not loaded."
+            val = "file didn't load."
         else:
-            val = "File is Loaded"
+            val = "file loaded"
             #val = "Custom file is loaded."
     else:
         val = user_db.get_var(var_name, sender_id)
