@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
-# (c) YashDK [yash-dk@github]
+
 
 from telethon import TelegramClient
 import asyncio
 
-class tkclient(TelegramClient):
+class tgtkclient(TelegramClient):
     def __init__(self,*args,**kwargs):
         super().__init__(*args,**kwargs)
         
